##############################################################################
#
# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
# 
# This software is subject to the provisions of the Zope Public License,
# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE
# 
##############################################################################
"""FolderFilter module

Defines the FolderFilterHolder class
"""

from Globals import DTMLFile, MessageDialog, Persistent
from OFS.SimpleItem import SimpleItem
from Acquisition import Implicit
from DateTime.DateTime import DateTime
from urllib import quote
from string import strip

class FolderFilterHolder(Persistent, SimpleItem, Implicit):
    """Provide a simple drop-in container for Folder Filters
    """

    meta_type='Folder Filter Holder'
    id = meta_type
    title = ''
    _filters = None
    
    __ac_permissions__=(('View management screens',
                         ('manage_main','pick_filter')),
                        )

    manage_options=({'label':'Edit', 'action':'manage_main'},)
    manage_main = DTMLFile('www/edit', globals(), __name__='manage_main')

    def pick_filter(self, REQUEST, RESPONSE, filter):
        '''Handle filter choice'''
        if filter == '_edit':
            RESPONSE.redirect(REQUEST['URLPATH1'] + '/manage_main')
            return
        if filter == '_all':
            filter = ''
            e='Wed, 31-Dec-97 23:59:59 GMT'
        else:
            e=(DateTime('GMT') + 3650).rfc822()
        RESPONSE.setCookie('zmi_folder_filter', str(filter),
                           path='/', expires=e)
        RESPONSE.redirect(REQUEST['URLPATH2'] + '/manage_workspace')

    def get_filter(self, name=None):
        if not self._filters:
            return
        if name is None:
            get = self.REQUEST.get
            name = get('filter')
            if not isinstance(name, type('')):
                name = get('zmi_folder_filter', '')
        return self._filters.get(name)

    def get_filters(self):
        return self._filters or {}

    def get_filter_ids(self, filter):
        ids = []
        if filter and filter.get('ids'):
            for idfilt in filter['ids']:
                ids.append({'kind': idfilt[0], 'idstr': idfilt[1]})
        ids.append({'kind': 0, 'idstr': ''})
        return ids

    def save_filter(self, REQUEST, RESPONSE, filter_name, filter_def):
        '''Save Filter'''
        filters = self._filters = self._filters or {}
        if hasattr(filter_def, 'delete'):
            del filters[filter_name]
        else:
            filters[filter_name] = filter = {'name': filter_name}
            mtmap = {}
            for mt in getattr(filter_def, 'meta_types', ()):
                mtmap[mt] = 1
            if mtmap:
                filter['meta_types'] = mtmap
                filter['mt_kind'] = filter_def.mt_kind
            ids = []
            for i in range(len(filter_def.idstr)):
                idstr = strip(filter_def.idstr[i])
                if idstr:
                    ids.append((not not filter_def.idkind[i], idstr))
            if ids:
                filter['ids'] = tuple(ids)
        RESPONSE.redirect(REQUEST['URLPATH1'] + '/manage_main?'
                          + 'filter=' + filter_name)


def manage_addFolderFilterHolder(self, REQUEST=None, submit=None):
    """ """
    ffh = FolderFilterHolder()
    self.this()._setObject(ffh.id, ffh)
    if REQUEST:
        try: u = self.DestinationURL()
        except: u = REQUEST['URL1']
        if submit==" Add and Edit ": u="%s/%s" % (u,quote(ffh.id))
        REQUEST.RESPONSE.redirect(u+'/manage_main')
        return
    return ffh

constructors = (
  ('manage_addFolderFilterHolderForm', DTMLFile('www/add', globals())),
  ('manage_addFolderFilterHolder', manage_addFolderFilterHolder),
)
